@@ -27,7 +27,6 @@ except ImportError:  # pragma: no cover
 
 
 from argparse import ArgumentParser, RawTextHelpFormatter
-from bisect import insort
 
 from six import StringIO
 
@@ -167,9 +166,10 @@ class SortedCDXWriter(BaseCDXWriter):
         super(SortedCDXWriter, self).write(entry, filename)
         line = self.out.getvalue()
         if line:
-            insort(self.sortlist, line)
+            self.sortlist.append(line)
 
     def __exit__(self, *args):
+        self.sortlist.sort()
         self.actual_out.write(''.join(self.sortlist))
         return False
 
@@ -331,13 +331,13 @@ are supported.
 Some examples:
 
 * Create "example.cdx" index from example.warc.gz
-{0} ./cdx/example.cdx ./warcs/example.warc.gz
+{0} --output ./cdx/example.cdx ./warcs/example.warc.gz
 
 * Create "combined.cdx", a combined, sorted index of all warcs in ./warcs/
-{0} --sort combined.cdx ./warcs/
+{0} --sort --output combined.cdx ./warcs/
 
 * Create a sorted cdx per file in ./cdx/ for each archive file in ./warcs/
-{0} --sort ./cdx/ ./warcs/
+{0} --sort --output ./cdx/ ./warcs/
 """.format(os.path.basename(sys.argv[0]))
 
     sort_help = """
@@ -451,7 +451,9 @@ instead of current working directory
                         action='store_true',
                         help=minimal_json_help)
 
-    parser.add_argument('output', nargs='?', default='-', help=output_help)
+    parser.add_argument('-o', '--output',
+                        default='-', help=output_help)
+
     parser.add_argument('inputs', nargs='+', help=input_help)
 
     cmd = parser.parse_args(args=args)
