@@ -15,7 +15,7 @@ This file is part of pywb, https://github.com/webrecorder/pywb
 
     You should have received a copy of the GNU General Public License
     along with pywb.  If not, see <http://www.gnu.org/licenses/>.
-   
+
 */
 
 // Creates the default pywb banner.
@@ -148,6 +148,10 @@ This file is part of pywb, https://github.com/webrecorder/pywb
    * @param {string} bid - The id for the banner
    */
   DefaultBanner.prototype.createBanner = function(bid) {
+    this.header = document.createElement('header');
+    this.header.setAttribute('role', 'banner');
+    this.nav = document.createElement('nav');
+
     this.banner = document.createElement('wb_div', true);
     this.banner.setAttribute('id', bid);
     this.banner.setAttribute('lang', 'en');
@@ -159,7 +163,7 @@ This file is part of pywb, https://github.com/webrecorder/pywb
 
       var logoContents = "";
       logoContents += "<img src='" + window.banner_info.logoImg + "' alt='" + window.banner_info.logoAlt + "'>";
-      logoContents += "<img src='" + window.banner_info.logoImg + "' class='mobile' alt='" + window.banner_info.logoAlt + "'>";
+      logoContents += "<img src='" + window.banner_info.logoImg + "' class='_wb_mobile' alt='" + window.banner_info.logoAlt + "'>";
 
       logo.innerHTML = logoContents;
       this.banner.appendChild(logo);
@@ -178,16 +182,16 @@ This file is part of pywb, https://github.com/webrecorder/pywb
     var calendarLink = document.createElement("a");
     calendarLink.setAttribute("id", "calendarLink");
     calendarLink.setAttribute("href", "#");
-    calendarLink.innerHTML = "<img src='" + calendarImg + "' alt='" + window.banner_info.calendarAlt + "'><span class='no-mobile'>&nbsp;" +window.banner_info.calendarLabel + "</span>";
+    calendarLink.innerHTML = "<img src='" + calendarImg + "' alt='" + window.banner_info.calendarAlt + "'><span class='_wb_no-mobile'>&nbsp;" +window.banner_info.calendarLabel + "</span>";
     ancillaryLinks.appendChild(calendarLink);
     this.calendarLink = calendarLink;
 
-    if (typeof window.banner_info.locales !== "undefined" && window.banner_info.locales.length) {
+    if (typeof window.banner_info.locales !== "undefined" && window.banner_info.locales.length > 1) {
       var locales = window.banner_info.locales;
       var languages = document.createElement("div");
 
       var label = document.createElement("span");
-      label.setAttribute("class", "no-mobile");
+      label.setAttribute("class", "_wb_no-mobile");
       label.appendChild(document.createTextNode(window.banner_info.choiceLabel + " "));
       languages.appendChild(label);
 
@@ -208,8 +212,9 @@ This file is part of pywb, https://github.com/webrecorder/pywb
     }
 
     this.banner.appendChild(ancillaryLinks);
-
-    document.body.insertBefore(this.banner, document.body.firstChild);
+    this.nav.appendChild(this.banner);
+    this.header.appendChild(this.nav);
+    document.body.insertBefore(this.header, document.body.firstChild);
   };
 
   /**
