@@ -22,6 +22,10 @@ import requests
 
 import re
 import logging
+import os
+
+
+no_verify = os.environ.get("PYWB_NO_VERIFY_SSL")
 
 
 #=============================================================================
@@ -46,6 +50,8 @@ class BaseIndexSource(object):
         self.sesh = requests.Session()
         self.sesh.mount('http://', adapter)
         self.sesh.mount('https://', adapter)
+        if no_verify:
+            self.sesh.verify = False
 
 
 #=============================================================================
@@ -113,7 +119,7 @@ class FileIndexSource(BaseIndexSource):
 class RemoteIndexSource(BaseIndexSource):
     CDX_MATCH_RX = re.compile('^cdxj?\+(?P<url>https?\:.*)')
 
-    def __init__(self, api_url, replay_url, url_field='load_url', closest_limit=10):
+    def __init__(self, api_url, replay_url, url_field='load_url', closest_limit=100):
         self.api_url = api_url
         self.replay_url = replay_url
         self.url_field = url_field
@@ -125,6 +131,9 @@ class RemoteIndexSource(BaseIndexSource):
         if 'closest' in params and self.closest_limit:
             api_url += '&limit=' + str(self.closest_limit)
 
+        if 'matchType' in params:
+            api_url += '&matchType=' + params.get('matchType')
+
         return api_url
 
     def load_index(self, params):
@@ -154,9 +163,9 @@ class RemoteIndexSource(BaseIndexSource):
         if name:
             source_coll = params.get('param.' + name + '.src_coll', '')
 
-        cdx[self.url_field] = self.replay_url.format(url=cdx['url'],
+        cdx[self.url_field] = res_template(self.replay_url, dict(url=cdx['url'],
                                                      timestamp=cdx['timestamp'],
-                                                     src_coll=source_coll)
+                                                     src_coll=source_coll))
     def __repr__(self):
         return '{0}({1}, {2})'.format(self.__class__.__name__,
                                       self.api_url,
@@ -245,7 +254,7 @@ class XmlQueryIndexSource(BaseIndexSource):
         try:
             limit = params.get('limit')
             if limit:
-                query = 'limit: {0} '.format(limit) + query
+                query = 'limit:{0} '.format(limit) + query
 
             # OpenSearch API requires double-escaping
             # TODO: add option to not double escape if needed
@@ -311,6 +320,11 @@ class XmlQueryIndexSource(BaseIndexSource):
         cdx['digest'] = self.gettext(item, 'digest')
         cdx['offset'] = self.gettext(item, 'compressedoffset')
         cdx['filename'] = self.gettext(item, 'file')
+
+        length = self.gettext(item, 'compressedendoffset')
+        if length:
+            cdx['length'] = length
+
         return cdx
 
     def gettext(self, item, name):
